@@ -8,7 +8,7 @@ from httpx import Client, HTTPError, Timeout
 from checkbox_api.client.base import BaseCheckBoxClient
 from checkbox_api.consts import DEFAULT_REQUESTS_RELAX
 from checkbox_api.exceptions import CheckBoxError, CheckBoxNetworkError, StatusException
-from checkbox_api.methods import cash_register, cashier, receipts, shifts
+from checkbox_api.methods import cash_register, cashier, receipts, shifts, transactions
 from checkbox_api.methods.base import AbstractMethod, BaseMethod
 from checkbox_api.storage.simple import SessionStorage
 
@@ -261,3 +261,33 @@ class CheckBoxClient(BaseCheckBoxClient):
                 f"{initial_transaction['response_error_message']!r}"
             )
         return shift
+
+    def get_offline_codes(self, count: int = 2000):
+        logger.info("Ask offline codes (count=%d)", count)
+        self(cash_register.AskOfflineCodes(count=count, sync=True))
+        logger.info("Load offline codes...")
+        codes = self(cash_register.GetOfflineCodes(count=count))
+        return [item["fiscal_code"] for item in codes]
+
+    def wait_transaction(
+        self,
+        transaction_id: str,
+        relax: int = DEFAULT_REQUESTS_RELAX,
+        timeout: Optional[int] = None,
+        storage: Optional[SessionStorage] = None,
+    ):
+        transaction = self._wait_status(
+            transactions.GetTransaction(transaction_id=transaction_id),
+            relax=relax,
+            timeout=timeout,
+            storage=storage,
+            field="status",
+            expected_value={"DONE", "ERROR"},
+        )
+        if transaction["status"] == "ERROR":
+            raise StatusException(
+                f"Transaction status moved to {transaction['status']!r} "
+                f"and tax status {transaction['response_status']!r} "
+                f"with message {transaction['response_error_message']!r}"
+            )
+        return transaction
