@@ -106,3 +106,15 @@ class GetReceiptVisualizationPdf(GetReceiptVisualization):
 class GetReceiptVisualizationQrCode(GetReceiptVisualization):
     def __init__(self, receipt_id: str):
         super().__init__(receipt_id=receipt_id, fmt="qrcode")
+
+
+class AddExternal(BaseMethod):
+    method = HTTPMethod.POST
+    uri = "receipts/add-external"
+
+    def __init__(self, data):
+        self.data = data
+
+    @property
+    def payload(self):
+        return self.data
